==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebFilteringExpressionsTreeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeDetailDescriptionMetadata } from "./WebFilteringExpressionsTreeDetailDescriptionMetadata";
import { WebFilteringExpressionsTreeEventArgsDescription } from "./WebFilteringExpressionsTreeEventArgsDescription";
/**
 * @hidden
 */
var WebFilteringExpressionsTreeEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFilteringExpressionsTreeEventArgsDescriptionMetadata, _super);
    function WebFilteringExpressionsTreeEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFilteringExpressionsTreeEventArgsDescriptionMetadata.b = function (a) {
        if (WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a == null) {
            WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFilteringExpressionsTreeEventArgsDescriptionMetadata.c(WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a);
        WebFilteringExpressionsTreeDetailDescriptionMetadata.d(a);
    };
    WebFilteringExpressionsTreeEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FilteringExpressionsTreeEventArgs");
        a.item("Detail", "ExportedType:WebFilteringExpressionsTreeDetail");
    };
    WebFilteringExpressionsTreeEventArgsDescriptionMetadata.d = function (a) {
        WebFilteringExpressionsTreeEventArgsDescriptionMetadata.b(a);
        a.ad("WebFilteringExpressionsTreeEventArgs", function () { return new WebFilteringExpressionsTreeEventArgsDescription(); });
        a.ac("WebFilteringExpressionsTreeEventArgs", WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a);
    };
    WebFilteringExpressionsTreeEventArgsDescriptionMetadata.$t = markType(WebFilteringExpressionsTreeEventArgsDescriptionMetadata, 'WebFilteringExpressionsTreeEventArgsDescriptionMetadata');
    WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a = null;
    return WebFilteringExpressionsTreeEventArgsDescriptionMetadata;
}(Base));
export { WebFilteringExpressionsTreeEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebFilteringExpressionsTreeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringExpressionsTreeDetailDescriptionMetadata } from "./WebFilteringExpressionsTreeDetailDescriptionMetadata";
import { WebFilteringExpressionsTreeEventArgsDescription } from "./WebFilteringExpressionsTreeEventArgsDescription";
/**
 * @hidden
 */
var WebFilteringExpressionsTreeEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFilteringExpressionsTreeEventArgsDescriptionMetadata, _super);
    function WebFilteringExpressionsTreeEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFilteringExpressionsTreeEventArgsDescriptionMetadata.b = function (a) {
        if (WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a == null) {
            WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFilteringExpressionsTreeEventArgsDescriptionMetadata.c(WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a);
        WebFilteringExpressionsTreeDetailDescriptionMetadata.d(a);
    };
    WebFilteringExpressionsTreeEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FilteringExpressionsTreeEventArgs");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("Detail", "ExportedType:WebFilteringExpressionsTreeDetail");
    };
    WebFilteringExpressionsTreeEventArgsDescriptionMetadata.d = function (a) {
        WebFilteringExpressionsTreeEventArgsDescriptionMetadata.b(a);
        a.ae("WebFilteringExpressionsTreeEventArgs", function () { return new WebFilteringExpressionsTreeEventArgsDescription(); });
        a.ad("WebFilteringExpressionsTreeEventArgs", WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a);
    };
    WebFilteringExpressionsTreeEventArgsDescriptionMetadata.$t = markType(WebFilteringExpressionsTreeEventArgsDescriptionMetadata, 'WebFilteringExpressionsTreeEventArgsDescriptionMetadata');
    WebFilteringExpressionsTreeEventArgsDescriptionMetadata.a = null;
    return WebFilteringExpressionsTreeEventArgsDescriptionMetadata;
}(Base));
export { WebFilteringExpressionsTreeEventArgsDescriptionMetadata };
